@@ -27,6 +27,7 @@ import sagemaker_inference
 from sagemaker_inference import default_handler_service, environment, logging, utils
 from sagemaker_inference.environment import code_dir
 
+logging.configure_logger()
 logger = logging.get_logger()
 
 MMS_CONFIG_FILE = os.path.join("/etc", "sagemaker-mms.properties")
@@ -150,6 +151,7 @@ def _generate_mms_config_properties():
         "default_workers_per_model": env.model_server_workers,
         "inference_address": "http://0.0.0.0:{}".format(env.inference_http_port),
         "management_address": "http://0.0.0.0:{}".format(env.management_http_port),
+        "vmargs": "-XX:-UseContainerSupport",
     }
 
     custom_configuration = str()
@@ -188,8 +190,8 @@ def _install_requirements():
         raise ValueError("failed to install required packages")
 
 
-# retry for 10 seconds
-@retry(stop_max_delay=10 * 1000)
+# retry for 10 minutes
+@retry(wait_fixed=1000, stop_max_delay=10 * 60 * 1000)
 def _retrieve_mms_server_process():
     mms_server_processes = list()
 
